**Example 1: 删除任务**

删除任务

Input: 

```
tccli tsf DeleteTask --cli-unfold-argument  \
    --TaskId task-qv9obht5e
```

Output: 
```
{
    "Response": {
        "RequestId": "6281ddf9-1914-420b-afb8-93735ac3270a",
        "Result": true
    }
}
```

